#
# spec file for package neatvnc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libsoname libneatvnc0

Name:           neatvnc
Version:        0.6.0
Release:        bp156.2.7
Summary:        A VNC server library
License:        ISC
Group:          System/GUI/Other
URL:            https://github.com/any1/neatvnc
Source0:        %url/archive/v%{version}.tar.gz

BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(aml) >= 0.3.0
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libturbojpeg)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(zlib)

%description
This is a VNC server library.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %libsoname = %{version}

%description    devel
Development files and headers for %{name}.

%package -n     %libsoname
Summary:        A VNC server library
Group:          System/Libraries

%description -n %libsoname
A VNC server library.

%prep
%autosetup -p1

%build
%meson

%meson_build

%install
%meson_install

%ldconfig_scriptlets -n %libsoname

%files devel
%license COPYING
%doc README.md
%{_includedir}/neatvnc.h
%{_libdir}/libneatvnc.so
%{_libdir}/pkgconfig/neatvnc.pc

%files -n %libsoname
%{_libdir}/libneatvnc.so.*

%changelog
* Mon Jan 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  Highlights:
  * The client now has control over h264 quality settings
  * Left & right scrolling is now supported
  * A custom framebuffer allocator function can now be assigned
  * The following functions have been added
    + A function for querying client side cursor support
    + A function to get the hostname of a connected client
    + A function to get the credentials of an authenticated client
    + A function for listing connected clients
    + A function for disconnecting a client
  Bug fixes:
  * A race condition when a client tries to resize the display before it has an encoder
  * Cursor buffers are now freed on close
  * Various race conditions in encoders
  * Spurious exits due to SIGPIPE
  * Occasional leaked buffers when clients disconnect
  * Clients no longer linger on exit with TLS
* Mon Dec 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- "Pkgconfigify" BuildRequires, align with what meson checks for.
- Modernize spec.
* Mon Nov  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.4:
  * This fixes stalling during h264 encoding. The FFmpeg devs
    seem to think that it's normal to change the default behaviour
    of their code, so this needs to be fixed here instead.
* Mon Nov  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.3:
  * Revert "h264-encoder: Add 30 bit color depth formats"
  * server: Fix encoding selection for sw frames
* Mon Nov  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.2:
  * stream: Remove stray ampersand in tls handshake failure code path
  * resampler: Use transformed width as destination stride
* Mon Nov  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.1:
  * meson: Use partial_dependency() for libdrm cflags
  * test: meson: Add missing libdrm_inc dependency
  * server: add missing header after f20ffb5e1efe
* Mon Nov  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.0:
  * H.264 Encoding
  * UNIX Sockets
  * New framebuffer submission API
  * Automatic buffer transforms
  * Client side cursor rendering
  * Now accepts DMA-BUFs
  * Presentation time stamps
  * New internal encoder abstraction layer
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 0.4.0:
  * This release adds support for the qemu extended key event. When this is
    also supported by the client, key codes will be used instead of symbols
    which eliminates the need for reverse key code lookup on the server-side.
* Wed Sep 30 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.2:
  * This release fixes a crash due to incorrect handling of fragmented packets
  and adds copy & paste support.
  * This release fixes a bug with tight encoding reported by Jeroen Hofstee
* Tue Jul 28 2020 Alexander Graul <alexander.graul@suse.com>
- Update to version 0.2.0
- Tight encoding is no longer experimental and also more complete.
  + The encoder employs multiple CPU cores, both for lossy and lossless
    compression, which makes it considerably faster than ZRLE, even with
    lossless compression.
  + Supports both lossy (JPEG) and lossless (DEFLATE) compression.
  + Allows the client to choose the JPEG "quality" level.
  + Allows the client to choose whether to enable lossy compression or not.
- Service-side resizing: the server can notify the client and resize buffers
  when a different display mode is set
- The API has been prepared for adding multi-display suppport. It has not been
  implemented, but the (hopefully) won't have to change when it is.
- Version info is baked into the library, so applications linking to neatvnc
  can report the version to the user.
- The server can now looks up the address to which to bind using getaddrinfo
* Sat Jun  6 2020 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies and conjecture from descriptions.
* Wed Jun  3 2020 Michael Vetter <mvetter@suse.com>
- Initial package of neatvnc in version 0.1.0 for openSUSE
